import gst, pygst, os, subprocess, threading, urllib2, random, time, gobject
from gstmanager.gstmanager import PipelineManager
pipeline_desc = "uridecodebin name=pipe1 pipe1. ! videobalance name=balance ! textoverlay name=text ! xvimagesink name=videosink pipe1. ! volume name=volume ! autoaudiosink"

class Player:
	def __init__(self, callback, xid):
		self.name = 'GStreamer'
		self.callback = callback
		self.xid = xid
		self.mprunning = False
		self.error = False
		self.locks = 0			# de cate ori timpul a ramas acelasi
		self.lastPos = -1		# ultima pozitie (ultimul timp)
		# folosim ultimele doua variabile pentru a determina daca stream-ul s-a blocat
		
	def play(self, url):
		self.pipelinel = PipelineManager(pipeline_desc)
		self.pipelinel.pipeline.get_by_name("videosink").set_xwindow_id(self.xid)
		self.error = False
		threading.Thread(target=self.prepareGST, args=(url, )).start()
		
	def prepareGST(self, url):
		self.pipelinel = PipelineManager(pipeline_desc)
		self.pipelinel.set_property_on_element(element_name="pipe1", property_name="uri", value=url)
		self.pipelinel.pipeline.get_by_name("videosink").set_xwindow_id(self.xid)
		self.pipelinel.run()
		state = self.pipelinel.get_state()
		while state != 'GST_STATE_PLAYING':
			if state == 'GST_STATE_READY':
				self.error = True
				break
			time.sleep(0.1)
		self.mprunning = True
		gobject.idle_add(self.callback)
	
	def pause(self):
		if hasattr(self, 'pipelinel'):
			self.pipelinel.pause()
		
	def stop(self):
		if hasattr(self, 'pipelinel'):
			self.pipelinel.stop()
			self.mprunning = False
		
	def volume(self, value):
		if hasattr(self, 'pipelinel'):
			self.pipelinel.set_property_on_element(element_name="volume", property_name="volume", value=value)
		
	def adjustImage(self, b, c, s):
		if hasattr(self, 'pipelinel'):
			b = float(b) / float(100)
			c = float(c + 100) / float(100)
			s = float(s + 100) / float(100)
			self.pipelinel.set_property_on_element(element_name="balance", property_name="brightness", value=b)
			self.pipelinel.set_property_on_element(element_name="balance", property_name="contrast", value=c)
			self.pipelinel.set_property_on_element(element_name="balance", property_name="saturation", value=s)
	
	def OSD(self, text):
		if hasattr(self, 'pipelinel'):
			self.pipelinel.set_property_on_element(element_name="text", property_name="halignment", value=0)
			self.pipelinel.set_property_on_element(element_name="text", property_name="valignment", value=2)
			self.pipelinel.set_property_on_element(element_name="text", property_name="line-alignment", value=0)
			self.pipelinel.set_property_on_element(element_name="text", property_name="font-desc", value="Sans Bold 24")
			self.pipelinel.set_property_on_element(element_name="text", property_name="text", value=text)
			if hasattr(self, "timeout"):
				gobject.source_remove(self.timeout)
				self.timeout = gobject.timeout_add(5000, self.hideOSD)
			else:
				self.timeout = gobject.timeout_add(5000, self.hideOSD)
		
	def hideOSD(self):
		if hasattr(self, 'pipelinel'):
			self.pipelinel.set_property_on_element(element_name="text", property_name="text", value="")
			return False
		
	def setRatio(self, ratio):
		return None # nu este necesar - imaginea se modifica dupa aspectratio-ul ferestrei de afisare din TV-MAXE.
	
	def getStatus(self):
		try:
			pos = self.pipelinel.get_position()
		except:
			pos = None
		if pos == self.lastPos:
			self.locks = self.locks + 1 # adaugam un "lock"
		self.lastPos = pos
		if self.locks > 20:
			self.error = True	# prea mult timp cat stream-ul a ramas blocat; eroare.
		return not self.error
	
	def isPlaying(self):
		return self.mprunning
	
	def quit(self):
		if hasattr(self, 'pipelinel'):
			self.pipelinel.stop()
		self.mprunning = False